@@ -37,10 +37,11 @@ void ContactMetaDataAttributeTest::clone()
     Akonadi::ContactMetaDataAttribute attribute1;
     attribute1.setMetaData(content1);
 
-    auto *attribute2 = static_cast<Akonadi::ContactMetaDataAttribute *>(attribute1.clone());
+    auto attribute2 = static_cast<Akonadi::ContactMetaDataAttribute *>(attribute1.clone());
     const QVariantMap content2 = attribute2->metaData();
 
     QVERIFY(content1 == content2);
+    delete attribute2;
 }
 
 void ContactMetaDataAttributeTest::serialization()
