@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,6 +24,6 @@ public:
     Q_REQUIRED_RESULT QString contactsToHtml(const KContacts::Addressee::List &contacts);
 
 private:
-    void init();
+    AKONADI_CONTACT_NO_EXPORT void init();
 };
 }
