@@ -11,7 +11,9 @@
 #include <Akonadi/Item>
 #include <KColorScheme>
 #include <KConfigGroup>
+
 #include <KContacts/Addressee>
+#include <kcontacts_version.h>
 
 #include <KLocalizedString>
 #include <KStringHandler>
@@ -95,22 +97,18 @@ QString StandardContactFormatter::toHtml(HtmlForm form) const
     }
 
     // Phone Numbers
-    int counter = 0;
-
     const auto phoneNumbers = rawContact.phoneNumbers();
     for (const KContacts::PhoneNumber &number : phoneNumbers) {
         QString dispLabel = number.typeLabel().replace(QLatin1Char(' '), QStringLiteral("&nbsp;"));
-        QString dispValue = QStringLiteral("<a href=\"phone:?index=%1\">%2</a>").arg(counter).arg(number.number().toHtmlEscaped());
+        QString dispValue = QStringLiteral("<a href=\"tel:%1\">%2</a>").arg(number.normalizedNumber()).arg(number.number().toHtmlEscaped());
         if (number.type() & KContacts::PhoneNumber::Cell) {
-            QString dispIcon = QStringLiteral("<a href=\"sms:?index=%1\" title=\"%2\"><img src=\"sms_icon\" align=\"top\"/>")
-                                   .arg(counter)
+            QString dispIcon = QStringLiteral("<a href=\"sms:%1\" title=\"%2\"><img src=\"sms_icon\" align=\"top\"/>")
+                                   .arg(number.normalizedNumber())
                                    .arg(i18nc("@info:tooltip", "Send SMS"));
             dynamicPart += rowFmtStr2.arg(dispLabel, dispValue, dispIcon);
         } else {
             dynamicPart += rowFmtStr1.arg(dispLabel, dispValue);
         }
-
-        ++counter;
     }
 
     // EMails
@@ -140,7 +138,6 @@ QString StandardContactFormatter::toHtml(HtmlForm form) const
     }
 
     // Addresses
-    counter = 0;
     const auto addresses = rawContact.addresses();
     for (const KContacts::Address &address : addresses) {
         QString formattedAddress;
@@ -153,11 +150,9 @@ QString StandardContactFormatter::toHtml(HtmlForm form) const
 
         formattedAddress.replace(QRegularExpression(QStringLiteral("\n+")), QStringLiteral("<br>"));
 
-        const QString url = QStringLiteral("<a href=\"address:?index=%1\" title=\"%2\"><img src=\"map_icon\" alt=\"%2\"/></a>")
-                                .arg(counter)
+        const QString url = QStringLiteral("<a href=\"%1\" title=\"%2\"><img src=\"map_icon\" alt=\"%2\"/></a>")
+                                .arg(address.geoUri().toString())
                                 .arg(i18nc("@info:tooltip", "Show address on map"));
-        counter++;
-
         dynamicPart += rowFmtStr2.arg(KContacts::Address::typeLabel(address.type()), formattedAddress, url);
     }
 
