@@ -12,7 +12,6 @@
 #include <Akonadi/Item>
 #include <KColorScheme>
 #include <KContacts/Addressee>
-#include <kcontacts_version.h>
 using namespace Akonadi;
 
 class Akonadi::StandardContactGroupFormatterPrivate
@@ -24,9 +23,7 @@ StandardContactGroupFormatter::StandardContactGroupFormatter()
 {
 }
 
-StandardContactGroupFormatter::~StandardContactGroupFormatter()
-{
-}
+StandardContactGroupFormatter::~StandardContactGroupFormatter() = default;
 
 QString StandardContactGroupFormatter::toHtml(HtmlForm form) const
 {
@@ -39,7 +36,7 @@ QString StandardContactGroupFormatter::toHtml(HtmlForm form) const
     }
 
     if (group.name().isEmpty() && group.count() == 0) { // empty group
-        return QString();
+        return {};
     }
 
     if (group.contactReferenceCount() != 0) {
@@ -80,12 +77,8 @@ QString StandardContactGroupFormatter::toHtml(HtmlForm form) const
         } else {
             KContacts::Addressee contact;
             contact.setFormattedName(data.name());
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-            contact.insertEmail(data.email());
-#else
             KContacts::Email email(data.email());
             contact.addEmail(email);
-#endif
             const QString fullEmail = QLatin1String("<a href=\"mailto:") + QString::fromLatin1(QUrl::toPercentEncoding(contact.fullEmail()))
                 + QStringLiteral("\">%1</a>").arg(contact.preferredEmail());
 
