@@ -21,9 +21,10 @@ using namespace ContactEditor;
 
 CustomFieldsListWidget::CustomFieldsListWidget(QWidget *parent)
     : QWidget(parent)
+    , mCustomFieldList(new QTreeView(this))
+    , mModel(new CustomFieldsModel(this))
 {
     auto topLayout = new QVBoxLayout(this);
-    mCustomFieldList = new QTreeView(this);
     mCustomFieldList->setObjectName(QStringLiteral("customfieldlist"));
     mCustomFieldList->setSortingEnabled(true);
     mCustomFieldList->setRootIsDecorated(false);
@@ -31,7 +32,6 @@ CustomFieldsListWidget::CustomFieldsListWidget(QWidget *parent)
     mCustomFieldList->setItemDelegate(customFieldDelegate);
     topLayout->addWidget(mCustomFieldList);
 
-    mModel = new CustomFieldsModel(this);
     auto proxyModel = new QSortFilterProxyModel(this);
     proxyModel->setDynamicSortFilter(true);
     proxyModel->setSourceModel(mModel);
