@@ -18,30 +18,30 @@ using namespace ContactEditor;
 
 WebWidget::WebWidget(QWidget *parent)
     : QWidget(parent)
+    , mWebSiteEdit(new PreferredLineEditWidget(this))
+    , mAddButton(new QToolButton(this))
+    , mRemoveButton(new QToolButton(this))
+    , mWebType(new ContactEditor::WebSelectTypeCombobox(this))
 {
     auto layout = new QHBoxLayout(this);
     layout->setSpacing(0);
     layout->setContentsMargins({});
 
-    mWebSiteEdit = new PreferredLineEditWidget(this);
     mWebSiteEdit->setTrapReturnKey(true);
     mWebSiteEdit->setPlaceholderText(i18n("Add a Web Site"));
     mWebSiteEdit->setObjectName(QStringLiteral("website"));
     layout->addWidget(mWebSiteEdit);
     connect(mWebSiteEdit, &PreferredLineEditWidget::preferredChanged, this, &WebWidget::slotPreferredChanged);
 
-    mWebType = new ContactEditor::WebSelectTypeCombobox(this);
     mWebType->setObjectName(QStringLiteral("webtype"));
     layout->addWidget(mWebType);
 
-    mAddButton = new QToolButton(this);
     mAddButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     mAddButton->setObjectName(QStringLiteral("addbutton"));
     mAddButton->setToolTip(i18n("Add a Web Site"));
     connect(mAddButton, &QToolButton::clicked, this, &WebWidget::slotAddWeb);
     layout->addWidget(mAddButton);
 
-    mRemoveButton = new QToolButton(this);
     mRemoveButton->setObjectName(QStringLiteral("removebutton"));
     mRemoveButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
     mRemoveButton->setToolTip(i18n("Remove Web Site"));
